@@ -1,10 +1,9 @@
 // -*- C++ -*-
 //===------------------------ regex_egrep.cpp -----------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 
@@ -25,7 +24,7 @@ const char * test_cases[] = {
 
 const size_t k_num_tests = sizeof(test_cases)/sizeof(test_cases[0]);
 
-int main ()
+int main(int, char**)
 {
 	for (size_t i = 0; i < k_num_tests; ++i)
 		{
