@@ -1,20 +1,14 @@
 // -*- C++ -*-
 //===----------------------------------------------------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 
 // UNSUPPORTED: c++98, c++03, c++11, c++14
 
-// The following compilers don't allow constexpr variables of non-literal type.
-// XFAIL: gcc-5, gcc-6
-// XFAIL: clang-3.5, clang-3.6, clang-3.7, clang-3.8
-// XFAIL: apple-clang-6, apple-clang-7, apple-clang-8
-
 // <variant>
 
 // template <class ...Types> class variant;
@@ -30,12 +24,18 @@
 #include "test_macros.h"
 #include "variant_test_helpers.hpp"
 
-int main() {
+
+int main(int, char**) {
   {
-    using V = std::variant<int, ConstexprTestTypes::NoCtors>;
+    using V = std::variant<int, long>;
     constexpr V v;
     static_assert(v.index() == 0, "");
   }
+  {
+    using V = std::variant<int, long>;
+    V v;
+    assert(v.index() == 0);
+  }
   {
     using V = std::variant<int, long>;
     constexpr V v(std::in_place_index<1>);
@@ -57,4 +57,6 @@ int main() {
     assert(v.index() == std::variant_npos);
   }
 #endif
+
+  return 0;
 }
